@@ -6,8 +6,8 @@ from adcircpy.forcing.base import Forcing
 
 class WindForcing(Forcing, ABC):
     def __init__(self, nws: int, interval_seconds: int):
+        super().__init__(interval_seconds)
         self.NWS = nws
-        self.WTIMINC = interval_seconds
 
     @abstractmethod
     def write(self, directory: PathLike, overwrite: bool = False):
