@@ -1,3 +1,4 @@
+from functools import lru_cache
 # from collections.abc import Mapping
 import pathlib
 
@@ -35,10 +36,11 @@ class OutputCollection(
         return [_ for _ in self._container.keys() if _ is not None]
 
     def _certify_output_type(self, inst, obj):
+        # TODO: should use _filetype attribute instead or create a Enum class
         if isinstance(inst, obj):
             return inst
         elif isinstance(inst, (str, pathlib.Path)):
-            return obj.open(inst, crs=self.crs)
+            return obj(inst, crs=self.crs)
 
     @property
     def maxele(self):
@@ -49,12 +51,9 @@ class OutputCollection(
         return self._crs
 
     @property
+    @lru_cache(maxsize=None)
     def _container(self):
-        try:
-            return self.__container
-        except AttributeError:
-            self.__container = dict()
-            return self.__container
+        return {}
 
     @property
     def _maxele(self):
